@@ -29,5 +29,5 @@ class L3Product(LandsatProduct):
         return 60.0
 
     def _set_product_type(self) -> None:
-        """Get products type"""
+        """Set products type"""
         self._set_mss_product_type(version=3)
