@@ -16,16 +16,17 @@
 # limitations under the License.
 """ Landsat products """
 import logging
-import os
 import tarfile
 from abc import abstractmethod
 from datetime import datetime
 from enum import unique
+from pathlib import Path
 from typing import Tuple, Union
 
 import geopandas as gpd
 import numpy as np
 import pandas as pd
+from cloudpathlib import CloudPath
 from lxml import etree
 from rasterio.enums import Resampling
 
@@ -82,14 +83,14 @@ class LandsatProduct(OpticalProduct):
 
     def __init__(
         self,
-        product_path: str,
-        archive_path: str = None,
-        output_path: str = None,
+        product_path: Union[str, CloudPath, Path],
+        archive_path: Union[str, CloudPath, Path] = None,
+        output_path: Union[str, CloudPath, Path] = None,
         remove_tmp: bool = False,
     ) -> None:
         # Private
         self._collection = None
-        self._quality_id = None
+        self._pixel_quality_id = None
 
         # Initialization from the super class
         super().__init__(product_path, archive_path, output_path, remove_tmp)
@@ -106,14 +107,23 @@ class LandsatProduct(OpticalProduct):
         self.tile_name = self._get_tile_name()
         self._collection = self._set_collection()
         if self._collection == LandsatCollection.COL_1:
-            self._quality_id = "_BQA"
-            self._nodata_band_id = "_BQA"
+            self._pixel_quality_id = "_BQA"
+            self._radsat_id = "_BQA"
             self.needs_extraction = True  # Too slow to read directly tar.gz files
         else:
-            self._quality_id = "_QA_RADSAT"
-            self._nodata_band_id = "_QA_PIXEL"
+            self._pixel_quality_id = "_QA_PIXEL"
+            self._radsat_id = "_QA_RADSAT"
             self.needs_extraction = False  # Fine to read .tar files
 
+        # Warning if GS or GT
+        if "GS" in self.name:
+            LOGGER.warning(
+                "This Landsat product %s could be badly georeferenced "
+                "as only systematic geometric corrections have been applied "
+                "(using the spacecraft ephemeris data).",
+                self.name,
+            )
+
         # Post init done by the super class
         super()._post_init()
 
@@ -165,7 +175,7 @@ class LandsatProduct(OpticalProduct):
         Returns:
             gpd.GeoDataFrame: Footprint as a GeoDataFrame
         """
-        nodata_band = self._get_path(self._nodata_band_id)
+        nodata_band = self._get_path(self._pixel_quality_id)
 
         # Vectorize the nodata band (rasters_rio is faster)
         footprint = rasters_rio.vectorize(
@@ -342,7 +352,6 @@ class LandsatProduct(OpticalProduct):
         Args:
             band_list (list): List of the wanted bands
             resolution (float): Useless here
-            size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
 
         Returns:
             dict: Dictionary containing the path of each queried band
@@ -358,7 +367,7 @@ class LandsatProduct(OpticalProduct):
 
             # Get clean band path
             clean_band = self._get_clean_band_path(band, resolution=resolution)
-            if os.path.isfile(clean_band):
+            if clean_band.is_file():
                 band_paths[band] = clean_band
             else:
                 try:
@@ -421,9 +430,9 @@ class LandsatProduct(OpticalProduct):
             else:
                 # FOR COLLECTION 1 AND 2
                 tar_ds = None
-                mtd_path = os.path.join(self.path, mtd_name)
+                mtd_path = self.path.joinpath(mtd_name)
 
-                if not os.path.isfile(mtd_path):
+                if not mtd_path.is_file():
                     raise FileNotFoundError(
                         f"Unable to find the metadata file associated with {self.path}"
                     )
@@ -459,7 +468,7 @@ class LandsatProduct(OpticalProduct):
         else:
             # Open XML metadata
             mtd_from_path = f"{self.name}_MTL.xml"
-            mtd_archived = f".*{self.name}_MTL.xml"
+            mtd_archived = f"{self.name}_MTL\.xml"
             mtd_data = self._read_mtd(mtd_from_path, mtd_archived)
 
         return mtd_data
@@ -493,7 +502,7 @@ class LandsatProduct(OpticalProduct):
         else:
             filename = files.get_filename(path)
 
-        if self._quality_id in filename or self._nodata_band_id in filename:
+        if self._pixel_quality_id in filename or self._radsat_id in filename:
             band_xda = rasters.read(
                 path,
                 resolution=resolution,
@@ -563,7 +572,7 @@ class LandsatProduct(OpticalProduct):
             XDS_TYPE: Cleaned band array
         """
         # Open QA band
-        landsat_qa_path = self._get_path(self._quality_id)
+        landsat_qa_path = self._get_path(self._radsat_id)
         qa_arr = self._read_band(
             landsat_qa_path, resolution=resolution, size=size
         ).data  # To np array
@@ -597,7 +606,7 @@ class LandsatProduct(OpticalProduct):
             sat, other = rasters.read_bit_array(qa_arr, [sat_id, other_id])
 
             # If collection 2, nodata has to be found in pixel QA file
-            landsat_stat_path = self._get_path(self._nodata_band_id)
+            landsat_stat_path = self._get_path(self._pixel_quality_id)
             pixel_arr = self._read_band(
                 landsat_stat_path, resolution=resolution, size=size
             ).data
@@ -733,7 +742,7 @@ class LandsatProduct(OpticalProduct):
 
         if bands:
             # Open QA band
-            landsat_qa_path = self._get_path(self._quality_id)
+            landsat_qa_path = self._get_path(self._pixel_quality_id)
             qa_arr = self._read_band(landsat_qa_path, resolution=resolution, size=size)
 
             if self.product_type == LandsatProductType.L1_OLCI:
