@@ -19,6 +19,7 @@
 import logging
 import os
 import re
+import tempfile
 import zipfile
 from datetime import datetime
 from enum import unique
@@ -28,7 +29,7 @@ import geopandas as gpd
 import numpy as np
 import xarray as xr
 from lxml import etree
-from rasterio import features
+from rasterio import features, transform
 from rasterio.enums import Resampling
 
 from eoreader.bands.alias import ALL_CLOUDS, CIRRUS, CLOUDS, RAW_CLOUDS, SHADOWS
@@ -247,10 +248,7 @@ class S2Product(OpticalProduct):
                     ][0]
             else:
                 # Search for the name of the folder into the S2 products
-                for root, folders, _ in os.walk(os.path.abspath(self.path)):
-                    for folder in folders:
-                        if folder == dir_name:
-                            s2_bands_folder[band] = os.path.join(root, folder)
+                s2_bands_folder[band] = next(self.path.glob(f"**/*/{dir_name}"))
 
         for band in band_list:
             if band not in s2_bands_folder:
@@ -288,7 +286,7 @@ class S2Product(OpticalProduct):
         for band in band_list:
             # Get clean band path
             clean_band = self._get_clean_band_path(band, resolution=resolution)
-            if os.path.isfile(clean_band):
+            if clean_band.is_file():
                 band_paths[band] = clean_band
             else:
                 try:
@@ -398,25 +396,35 @@ class S2Product(OpticalProduct):
         else:
             band_name = band
 
-        if self.is_archived:
-            # Open the zip file
-            # WE DON'T KNOW WHY BUT DO NOT USE files.read_archived_vector HERE !!!
-            with zipfile.ZipFile(self.path, "r") as zip_ds:
-                filenames = [f.filename for f in zip_ds.filelist]
-                regex = re.compile(
-                    f".*GRANULE.*QI_DATA.*MSK_{mask_str}_B{band_name}.gml"
+        tmp_dir = tempfile.TemporaryDirectory()
+        try:
+            if self.is_archived:
+                # Open the zip file
+                # WE DON'T KNOW WHY BUT DO NOT USE files.read_archived_vector HERE !!!
+                with zipfile.ZipFile(self.path, "r") as zip_ds:
+                    filenames = [f.filename for f in zip_ds.filelist]
+                    regex = re.compile(
+                        f".*GRANULE.*QI_DATA.*MSK_{mask_str}_B{band_name}.gml"
+                    )
+                    mask_path = zip_ds.extract(
+                        list(filter(regex.match, filenames))[0], tmp_dir.name
+                    )
+            else:
+                # Get mask path
+                mask_path = files.get_file_in_dir(
+                    self.path,
+                    f"**/*GRANULE/*/QI_DATA/MSK_{mask_str}_B{band_name}.gml",
+                    exact_name=True,
                 )
-                with zip_ds.open(list(filter(regex.match, filenames))[0]) as mask_path:
-                    mask = vectors.open_gml(mask_path, crs=self.crs())
-        else:
-            qi_data_path = os.path.join(self.path, "GRANULE", "*", "QI_DATA")
 
-            # Get mask path
-            mask_path = files.get_file_in_dir(
-                qi_data_path, f"MSK_{mask_str}_B{band_name}.gml", exact_name=True
-            )
+            # Read vector
+            mask = vectors.read(mask_path, crs=self.crs())
 
-            mask = vectors.open_gml(mask_path, crs=self.crs())
+        except Exception as ex:
+            raise InvalidProductError(ex) from ex
+
+        finally:
+            tmp_dir.cleanup()
 
         return mask
 
@@ -442,9 +450,6 @@ class S2Product(OpticalProduct):
         Returns:
             XDS_TYPE: Cleaned band array
         """
-        nodata_true = 1
-        nodata_false = 0
-
         # Get detector footprint to deduce the outside nodata
         nodata_det = self.open_mask(
             "DETFOO", band
@@ -454,9 +459,11 @@ class S2Product(OpticalProduct):
         mask = features.rasterize(
             nodata_det.geometry,
             out_shape=(band_arr.rio.height, band_arr.rio.width),
-            fill=nodata_true,  # Outside detector = nodata
-            default_value=nodata_false,  # Inside detector = acceptable value
-            transform=band_arr.rio.transform(),
+            fill=self._mask_true,  # Outside detector = nodata (inverted compared to the usual)
+            default_value=self._mask_false,  # Inside detector = not nodata
+            transform=transform.from_bounds(
+                *band_arr.rio.bounds(), band_arr.rio.width, band_arr.rio.height
+            ),
             dtype=np.uint8,
         )
 
@@ -482,13 +489,15 @@ class S2Product(OpticalProduct):
             mask_pix = features.rasterize(
                 nodata_pix.geometry,
                 out_shape=(band_arr.rio.height, band_arr.rio.width),
-                fill=nodata_false,  # OK pixels = OK value
-                default_value=nodata_true,  # Discarded pixels = nodata
-                transform=band_arr.rio.transform(),
+                fill=self._mask_false,  # Outside vector
+                default_value=self._mask_true,  # Inside vector
+                transform=transform.from_bounds(
+                    *band_arr.rio.bounds(), band_arr.rio.width, band_arr.rio.height
+                ),
                 dtype=np.uint8,
             )
 
-            mask[mask_pix] = nodata_true
+            mask[mask_pix] = self._mask_true
 
         return self._set_nodata_mask(band_arr, mask)
 
@@ -570,8 +579,8 @@ class S2Product(OpticalProduct):
         Returns:
             (etree._Element, dict): Metadata XML root and its namespaces
         """
-        mtd_from_path = os.path.join("GRANULE", "*", "*.xml")
-        mtd_archived = ".*GRANULE.*\.xml"
+        mtd_from_path = "GRANULE/*/*.xml"
+        mtd_archived = "GRANULE.*\.xml"
 
         return self._read_mtd(mtd_from_path, mtd_archived)
 
@@ -605,11 +614,15 @@ class S2Product(OpticalProduct):
         band_dict = {}
 
         if bands:
-            def_band = self.get_default_band()
             cloud_vec = self.open_mask("CLOUDS", "00")
 
             # Open a bands to mask it
-            def_band = self.load(def_band, resolution=resolution)[def_band]
+            def_band = self._read_band(
+                self.get_default_band_path(),
+                self.get_default_band(),
+                resolution=resolution,
+                size=size,
+            )
             nodata = np.where(np.isnan(def_band), 1, 0)
 
             for band in bands:
@@ -657,11 +670,19 @@ class S2Product(OpticalProduct):
             if geometry.crs != xds.rio.crs:
                 geometry = geometry.to_crs(xds.rio.crs)
 
-            # Mask the file -> do not use rasterize to get a correct nodata mask !
-            rstrzd = rasters.mask(xds, geometry.geometry, nodata=xds.rio.encoded_nodata)
+            # Rasterize mask
+            cond = features.rasterize(
+                geometry.geometry,
+                out_shape=(xds.rio.height, xds.rio.width),
+                fill=self._mask_false,  # Pixels outside mask
+                default_value=self._mask_true,  # Pixels inside mask
+                transform=transform.from_bounds(
+                    *xds.rio.bounds(), xds.rio.width, xds.rio.height
+                ),
+                dtype=np.uint8,
+            )
+            cond = np.expand_dims(cond, axis=0)
 
-            # Get cloud raster
-            cond = np.where(rstrzd.data > 0, self._mask_true, self._mask_false)
         else:
             # If empty geometry, just
             cond = np.full(
